@@ -5,7 +5,7 @@ from zope.interface import implements
 from twisted.internet import defer
 from twisted.cred import checkers, error, credentials
 
-from swftp.swift import SwiftConnection, UnAuthenticated
+from swftp.swift import SwiftConnection, UnAuthenticated, UnAuthorized
 from swftp.utils import USER_AGENT
 
 
@@ -17,9 +17,10 @@ class SwiftBasedAuthDB:
     """
     implements(checkers.ICredentialsChecker)
 
-    def __init__(self, auth_url=None, pool=None):
+    def __init__(self, auth_url=None, pool=None, verbose=False):
         self.auth_url = auth_url
         self.pool = pool
+        self.verbose = verbose
 
     credentialInterfaces = (
         credentials.IUsernamePassword,
@@ -32,7 +33,9 @@ class SwiftBasedAuthDB:
         creds = credentials.IUsernamePassword(c, None)
         if creds is not None:
             conn = SwiftConnection(
-                self.auth_url, creds.username, creds.password, pool=self.pool)
+                self.auth_url, creds.username, creds.password,
+                pool=self.pool,
+                verbose=self.verbose)
             conn.user_agent = USER_AGENT
             d = conn.authenticate()
             d.addCallback(self._after_auth, conn)
@@ -42,5 +45,5 @@ class SwiftBasedAuthDB:
 
 
 def failed_auth(failure):
-    failure.trap(UnAuthenticated)
+    failure.trap(UnAuthenticated, UnAuthorized)
     return defer.fail(error.UnauthorizedLogin())
